@@ -15,12 +15,12 @@ class Serve(BaseCommand):
        'django.template.loaders.filesystem.load_template_source',
        'django.template.loaders.app_directories.load_template_source',
                            ),
-                           ROOT_URLCONF='billy.site.urls',
+                           ROOT_URLCONF='billy.web.urls',
                            INSTALLED_APPS=('django.contrib.humanize',
                                            'django.contrib.staticfiles',
-                                           'billy.site.api',
-                                           'billy.site.browse',
-                                           'billy.site.www',
+                                           'billy.web.api',
+                                           'billy.web.admin',
+                                           'billy.web.public',
                                           ),
                            DATE_FORMAT='Y-m-d',
                            TIME_FORMAT='H:i:s',
