@@ -65,6 +65,16 @@ def import_votes(data_dir):
     logger.info('imported %s vote files' % len(paths))
     return votes
 
+def oysterize_version(bill, version):
+    titles = [bill['title']] + bill.get('alternate_titles', [])
+    oysterize(version['url'], bill['state'] + ':billtext',
+              id=version['doc_id'],
+              # metadata
+              state=bill['state'], session=bill['session'],
+              chamber=bill['chamber'], bill_id=bill['bill_id'],
+              title=' , '.join(titles),
+             )
+
 
 def import_bill(data, votes, categorizer, oyster_documents=False):
     level = data['level']
@@ -148,13 +158,8 @@ def import_bill(data, votes, categorizer, oyster_documents=False):
 
     for version in data['versions']:
         # push versions to oyster
-        if oyster_documents:
-            oysterize(version['url'], data['state'] + ':billtext',
-                      id=version['doc_id'],
-                      # metadata
-                      name=version['name'], state=data['state'],
-                      session=data['session'], chamber=data['chamber'],
-                      bill_id=data['bill_id'])
+        if oyster_documents and 'url' in version:
+            oysterize_version(data, version)
 
         # Merge any version titles into the alternate_titles list
         if 'title' in version:
@@ -212,9 +217,9 @@ def import_bills(abbr, data_dir, oyster_documents=False):
         logger.debug('Failed to match vote %s %s %s' % tuple([
             r.encode('ascii', 'replace') for r in remaining]))
 
-    #meta = db.metadata.find_one({'_id': abbr})
-    #level = meta['level']
-    #populate_current_fields(level, abbr)
+    meta = db.metadata.find_one({'_id': abbr})
+    level = meta['level']
+    populate_current_fields(level, abbr)
 
     ensure_indexes()
 
