@@ -115,9 +115,15 @@ class Vote(SourcedObject):
         if self['yes_votes'] or self['no_votes'] or self['other_votes']:
             # If we have *any* specific votes, then validate the counts
             # for all types.
-            assert len(self['yes_votes']) == self['yes_count']
-            assert len(self['no_votes']) == self['no_count']
-            assert len(self['other_votes']) == self['other_count']
+            for type in ('yes', 'no', 'other'):
+                votes = len(self[type+'_votes'])
+                count = self[type+'_count']
+                if votes != count:
+                    raise ValueError('bad %s vote count for %s %s votes=%s count=%s' %
+                                     (type, self['bill_id'], self['motion'],
+                                      votes, count))
+
+
 
     def get_filename(self):
         filename = '%s_%s_%s_seq%s.json' % (self['session'],
